import { ChangeDetectorRef, ElementRef } from '@angular/core';
import { IgxSelectionAPIService } from '../core/selection';
import { IGroupByRecord } from '../data-operations/groupby-record.interface';
import { IgxGridAPIService } from './api.service';
import { IgxGridComponent } from './grid.component';
export declare class IgxGridGroupByRowComponent {
    gridAPI: IgxGridAPIService;
    private selection;
    element: ElementRef;
    cdr: ChangeDetectorRef;
    constructor(gridAPI: IgxGridAPIService, selection: IgxSelectionAPIService, element: ElementRef, cdr: ChangeDetectorRef);
    /**
     * @hidden
     */
    protected defaultCssClass: string;
    /**
     * @hidden
     */
    protected paddingIndentationCssClass: string;
    /**
     * @hidden
     */
    protected isFocused: boolean;
    /**
     * Returns whether the row is focused.
     * ```
     * let gridRowFocused = this.grid1.rowList.first.focused;
     * ```
     */
    readonly focused: boolean;
    /**
     * An @Input property that sets the index of the row.
     * ```html
     * <igx-grid-groupby-row [gridID]="id" [index]="rowIndex" [groupRow]="rowData" #row></igx-grid-groupby-row>
     * ```
     */
    index: number;
    /**
     * An @Input property that sets the id of the grid the row belongs to.
     * ```html
     * <igx-grid-groupby-row [gridID]="id" [index]="rowIndex" [groupRow]="rowData" #row></igx-grid-groupby-row>
     * ```
     */
    gridID: string;
    /**
     * An @Input property that specifies the group record the component renders for.
     * ```typescript
     * <igx-grid-groupby-row [gridID]="id" [index]="rowIndex" [groupRow]="rowData" #row></igx-grid-groupby-row>
     * ```
     */
    groupRow: IGroupByRecord;
    /**
     * Returns a reference of the content of the group.
     * ```typescript
     * const groupRowContent = this.grid1.rowList.first.groupContent;
     * ```
     */
    groupContent: ElementRef;
    /**
     * Returns whether the group row is expanded.
     * ```typescript
     * const groupRowExpanded = this.grid1.rowList.first.expanded;
     * ```
     */
    readonly expanded: boolean;
    /**
     * @hidden
     */
    tabindex: number;
    /**
     * @hidden
     */
    readonly describedBy: string;
    /**
     * Returns a reference to the underlying HTML element.
     * ```typescript
     * const groupRowElement = this.nativeElement;
     * ```
     */
    readonly nativeElement: HTMLElement;
    /**
     * Returns the style classes applied to the group rows.
     * ```typescript
     * const groupCssStyles = this.grid1.rowList.first.styleClasses;
     * ```
     */
    readonly styleClasses: string;
    /**
     * Toggles the group row.
     * ```typescript
     * this.grid1.rowList.first.toggle()
     * ```
     */
    toggle(): void;
    /**
     * @hidden
     */
    onKeydown(event: any): void;
    /**
     * Returns a reference to the `IgxGridComponent` the `IgxGridGroupByRowComponent` belongs to.
     * ```typescript
     * this.grid1.rowList.first.grid;
     * ```
     */
    readonly grid: IgxGridComponent;
    /**
     * @hidden
     */
    readonly dataType: any;
    /**
     * @hidden
     */
    onKeydownArrowDown(event: any): void;
    /**
     * @hidden
     */
    onKeydownArrowUp(event: any): void;
    /**
     * @hidden
     */
    onFocus(): void;
    /**
     * @hidden
     */
    onBlur(): void;
    private _getSelectedColIndex();
    private _getPrevSelectedColIndex();
}
